@@ -5,7 +5,7 @@ rescue LoadError
 end
 
 if defined?(Curl)
-  WebMock::VersionChecker.new('Curb', Curl::CURB_VERSION, '0.7.16').check_version!
+  WebMock::VersionChecker.new('Curb', Curl::CURB_VERSION, '0.7.16', '0.8.7').check_version!
 
   module WebMock
     module HttpLibAdapters
@@ -54,8 +54,8 @@ if defined?(Curl)
 
   module Curl
     class WebMockCurlEasy < Curl::Easy
-      def curb_or_webmock
 
+      def curb_or_webmock
         request_signature = build_request_signature
         WebMock::RequestRegistry.instance.requested_signatures.put(request_signature)
 
@@ -143,9 +143,9 @@ if defined?(Curl)
       end
 
       def invoke_curb_callbacks
-        @on_progress.call(0.0,1.0,0.0,1.0) if @on_progress
-        self.header_str.lines.each { |header_line| @on_header.call header_line } if @on_header
-        if @on_body
+        @on_progress.call(0.0,1.0,0.0,1.0) if defined?( @on_progress )
+        self.header_str.lines.each { |header_line| @on_header.call header_line } if defined?( @on_header )
+        if defined?( @on_body )
           if chunked_response?
             self.body_str.each do |chunk|
               @on_body.call(chunk)
@@ -154,18 +154,20 @@ if defined?(Curl)
             @on_body.call(self.body_str)
           end
         end
-        @on_complete.call(self) if @on_complete
+        @on_complete.call(self) if defined?( @on_complete )
 
         case response_code
         when 200..299
-          @on_success.call(self) if @on_success
-        when 400..599
-          @on_failure.call(self, self.response_code) if @on_failure
+          @on_success.call(self) if defined?( @on_success )
+        when 400..499
+          @on_missing.call(self, self.response_code) if defined?( @on_missing )
+        when 500..599
+          @on_failure.call(self, self.response_code) if defined?( @on_failure )
         end
       end
 
       def chunked_response?
-        @transfer_encoding == 'chunked' && self.body_str.respond_to?(:each)
+        defined?( @transfer_encoding ) && @transfer_encoding == 'chunked' && self.body_str.respond_to?(:each)
       end
 
       def build_webmock_response
@@ -236,28 +238,28 @@ if defined?(Curl)
       end
 
       def body_str
-        @body_str || super
+        @body_str ||= super
       end
       alias body body_str
 
       def response_code
-        @response_code || super
+        @response_code ||= super
       end
 
       def header_str
-        @header_str || super
+        @header_str ||= super
       end
       alias head header_str
 
       def last_effective_url
-        @last_effective_url || super
+        @last_effective_url ||= super
       end
 
       def content_type
-        @content_type || super
+        @content_type ||= super
       end
 
-      %w[ success failure header body complete progress ].each do |callback|
+      %w[ success failure missing header body complete progress ].each do |callback|
         class_eval <<-METHOD, __FILE__, __LINE__
           def on_#{callback} &block
             @on_#{callback} = block
