@@ -210,6 +210,18 @@ module WebMock
   end
 end
 
+# patch for StringIO behavior in Ruby 2.2.3
+# https://github.com/bblimke/webmock/issues/558
+class PatchedStringIO < StringIO #:nodoc:
+
+  alias_method :orig_read_nonblock, :read_nonblock
+
+  def read_nonblock(size, *args)
+    orig_read_nonblock(size)
+  end
+
+end
+
 class StubSocket #:nodoc:
 
   attr_accessor :read_timeout, :continue_timeout
@@ -235,10 +247,12 @@ module Net  #:nodoc: all
       @debug_output = debug_output
 
       @io = case io
-      when Socket, OpenSSL::SSL::SSLSocket, IO, StringIO
+      when Socket, OpenSSL::SSL::SSLSocket, IO
         io
+      when StringIO
+        PatchedStringIO.new(io.string)
       when String
-        StringIO.new(io)
+        PatchedStringIO.new(io)
       end
       raise "Unable to create local socket" unless @io
     end
@@ -272,10 +286,9 @@ module WebMock
       method = request.method.downcase.to_sym
 
       headers = Hash[*request.to_hash.map {|k,v| [k, v]}.inject([]) {|r,x| r + x}]
-
+      validate_headers(headers)
       headers.reject! {|k,v| k =~ /[Aa]uthorization/ && v.first =~ /^Basic / } #we added it to url userinfo
 
-
       if request.body_stream
         body = request.body_stream.read
         request.body_stream = nil
@@ -290,6 +303,21 @@ module WebMock
       WebMock::RequestSignature.new(method, uri, :body => request.body, :headers => headers)
     end
 
+    def self.validate_headers(headers)
+      # If you make a request with headers that are symbols Net::HTTP raises a NoMethodError
+      #
+      # WebMock normalizes headers when creating a RequestSignature,
+      # and will update all headers from symbols to strings.
+      #
+      # This could create a false positive in a test suite with WebMock.
+      #
+      # So before this point, WebMock raises an ArgumentError if any of the headers are symbols
+      # instead of the cryptic NoMethodError "undefined method `split' ...` from Net::HTTP
+      header_as_symbol = headers.keys.find {|header| header.is_a? Symbol}
+      if header_as_symbol
+        raise ArgumentError.new("Net:HTTP does not accept headers as symbols")
+      end
+    end
 
     def self.check_right_http_connection
       @was_right_http_connection_loaded = defined?(RightHttpConnection)
