@@ -20,6 +20,7 @@ module WebMock
     end
 
     def with(options = {}, &block)
+      raise ArgumentError.new('#with method invoked with no arguments. Either options hash or block must be specified.') if options.empty? && !block_given?
       assign_options(options)
       @with_block = block
       self
@@ -49,6 +50,7 @@ module WebMock
 
     def assign_options(options)
       options = WebMock::Util::HashKeysStringifier.stringify_keys!(options, :deep => true)
+      HashValidator.new(options).validate_keys('body', 'headers', 'query')
       @body_pattern = BodyPattern.new(options['body']) if options.has_key?('body')
       @headers_pattern = HeadersPattern.new(options['headers']) if options.has_key?('headers')
       @uri_pattern.add_query_params(options['query']) if options.has_key?('query')
@@ -135,7 +137,7 @@ module WebMock
       else
         # WebMock checks the query, Addressable checks everything else
         WebMock::Util::URI.variations_of_uri_as_strings(uri.omit(:query)).any? { |u| @pattern.match(u) } &&
-        (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query))
+          @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query)
       end
     end
 
@@ -198,6 +200,8 @@ module WebMock
       'text/plain'             => :plain
     }
 
+    attr_reader :pattern
+
     def initialize(pattern)
       @pattern = if pattern.is_a?(Hash)
         normalize_hash(pattern)
