@@ -35,7 +35,11 @@ module WebMock
     alias == eql?
 
     def url_encoded?
-      headers && headers['Content-Type'] == 'application/x-www-form-urlencoded'
+      !!(headers && headers['Content-Type'] == 'application/x-www-form-urlencoded')
+    end
+
+    def json_headers?
+      !!(headers && headers['Content-Type'] == 'application/json')
     end
 
     private
