@@ -79,7 +79,7 @@ module WebMock::Util
       def collect_query_hash(query_array, empty_accumulator, options)
         query_array.compact.inject(empty_accumulator.dup) do |accumulator, (key, value)|
           value = if value.nil?
-                    true
+                    nil
                   else
                     ::Addressable::URI.unencode_component(value.gsub(/\+/, ' '))
                   end
@@ -196,7 +196,11 @@ module WebMock::Util
           end
           # Useful default for OAuth and caching.
           # Only to be used for non-Array inputs. Arrays should preserve order.
-          new_query_values.sort!
+          begin
+            new_query_values.sort! # may raise for non-comparable values
+          rescue NoMethodError, ArgumentError
+            # ignore
+          end
         end
 
         buffer = ''
@@ -241,7 +245,7 @@ module WebMock::Util
         when ::Hash
           value = value.map do |key, val|
             [
-              ::Addressable::URI.encode_component(key.dup, ::Addressable::URI::CharacterClasses::UNRESERVED),
+              ::Addressable::URI.encode_component(key.to_s.dup, ::Addressable::URI::CharacterClasses::UNRESERVED),
               val
             ]
           end
@@ -259,7 +263,7 @@ module WebMock::Util
             buffer << "#{to_query(new_parent, val, options)}&"
           end
           buffer.chop
-        when TrueClass
+        when NilClass
           parent
         else
           encoded_value = Addressable::URI.encode_component(
