@@ -20,14 +20,14 @@ describe "HTTPClient" do
     http_request(:get, "http://www.example.com/") do |body|
       response_body = body
     end
-    response_body.should == "abc"
+    expect(response_body).to eq("abc")
   end
 
   it "should match requests if headers are the same  but in different order" do
     stub_request(:get, "www.example.com").with(:headers => {"a" => ["b", "c"]} )
-    http_request(
+    expect(http_request(
       :get, "http://www.example.com/",
-    :headers => {"a" => ["c", "b"]}).status.should == "200"
+    :headers => {"a" => ["c", "b"]}).status).to eq("200")
   end
 
   describe "when using async requests" do
@@ -44,7 +44,17 @@ describe "HTTPClient" do
     HTTPClient.get_content('www.example.com') do |content|
       str << content
     end
-    str.should == 'test'
+    expect(str).to eq('test')
+  end
+
+  it "should work via JSONClient subclass" do
+    stub_request(:get, 'www.example.com').to_return(
+      :status => 200,
+      :body => '{"test": "foo"}',
+      :headers => {'Content-Type' => 'application/json'}
+    )
+    content = JSONClient.get('www.example.com').content
+    expect(content).to eq("test" => "foo")
   end
 
   context "multipart bodies" do
@@ -91,12 +101,12 @@ describe "HTTPClient" do
     end
 
     it "supports request filters" do
-      @client.request(:get, 'http://www.example.com/').status.should == 200
+      expect(@client.request(:get, 'http://www.example.com/').status).to eq(200)
     end
 
     it "supports response filters" do
       res = @client.request(:get, 'http://www.example.com/')
-      res.header['X-Powered-By'].first.should == 'webmock'
+      expect(res.header['X-Powered-By'].first).to eq('webmock')
     end
   end
 
@@ -113,17 +123,18 @@ describe "HTTPClient" do
         nil # to let the request be made for real
       end
 
-      # To make two requests that have the same request signature, the headers must match.
-      # Since the webmock server has a Set-Cookie header, the 2nd request will automatically
-      # include a Cookie header (due to how httpclient works), so we have to set the header
-      # manually on the first request but not on the 2nd request.
-      http_request(:get, webmock_server_url, :client => client,
-                         :headers => { "Cookie" => "bar=; foo=" })
-      http_request(:get, webmock_server_url, :client => client)
+      http_request(:get, webmock_server_url, :client => client, :headers => { "Cookie" => "bar=; foo=" })
 
-      request_signatures.should have(2).signatures
+      if defined? HTTP::CookieJar
+        http_request(:get, webmock_server_url, :client => client, :headers => { "Cookie" => "bar=; foo=" })
+      else
+        # If http-cookie is not present, then the cookie headers will saved between requests
+        http_request(:get, webmock_server_url, :client => client)
+      end
+
+      expect(request_signatures.size).to eq(2)
       # Verify the request signatures were identical as needed by this example
-      request_signatures.first.should eq(request_signatures.last)
+      expect(request_signatures.first).to eq(request_signatures.last)
     end
   end
 
@@ -157,7 +168,7 @@ describe "HTTPClient" do
     it 'receives request_method, request_uri, and request_query from the request header' do
       stub_request :get, 'www.example.com'
       message = HTTPClient.new.get 'www.example.com'
-      message.header.request_uri.to_s.should == 'www.example.com'
+      expect(message.header.request_uri.to_s).to eq('www.example.com')
     end
   end
 end
