@@ -6,6 +6,9 @@ unless RUBY_PLATFORM =~ /java/
   require 'em-http'
   require 'typhoeus'
 end
+if RUBY_PLATFORM =~ /java/
+  require 'manticore'
+end
 
 $LOAD_PATH.unshift(File.dirname(__FILE__))
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
@@ -45,6 +48,7 @@ RSpec.configure do |config|
   config.filter_run :focus => true
   config.run_all_when_everything_filtered = true
 end
+RSpec::Expectations.configuration.warn_about_potential_false_positives = false
 
 def fail()
   raise_error(RSpec::Expectations::ExpectationNotMetError)
@@ -53,9 +57,3 @@ end
 def fail_with(message)
   raise_error(RSpec::Expectations::ExpectationNotMetError, message)
 end
-
-class Proc
-  def should_pass
-    lambda { self.call }.should_not raise_error
-  end
-end
