@@ -81,37 +81,37 @@ describe WebMock::Util::URI do
 
     it "should find all variations of the same uri for all variations of uri with params and path" do
       URIS_WITH_PATH_AND_PARAMS.each do |uri|
-        WebMock::Util::URI.variations_of_uri_as_strings(uri).sort.should == URIS_WITH_PATH_AND_PARAMS
+        expect(WebMock::Util::URI.variations_of_uri_as_strings(uri).sort).to eq(URIS_WITH_PATH_AND_PARAMS)
       end
     end
 
     it "should find all variations of the same uri for all variations of uri with params but without path" do
       URIS_WITHOUT_PATH_BUT_WITH_PARAMS.each do |uri|
-        WebMock::Util::URI.variations_of_uri_as_strings(uri).sort.should == URIS_WITHOUT_PATH_BUT_WITH_PARAMS
+        expect(WebMock::Util::URI.variations_of_uri_as_strings(uri).sort).to eq(URIS_WITHOUT_PATH_BUT_WITH_PARAMS)
       end
     end
 
     it "should find all variations of the same uri for all variations of uri without params or path" do
       URIS_WITHOUT_PATH_OR_PARAMS.each do |uri|
-        WebMock::Util::URI.variations_of_uri_as_strings(uri).sort.should == URIS_WITHOUT_PATH_OR_PARAMS
+        expect(WebMock::Util::URI.variations_of_uri_as_strings(uri).sort).to eq(URIS_WITHOUT_PATH_OR_PARAMS)
       end
     end
 
     it "should find all variations of the same uri for all variations of uri with auth" do
       URIS_WITH_AUTH.each do |uri|
-        WebMock::Util::URI.variations_of_uri_as_strings(uri).sort.should == URIS_WITH_AUTH
+        expect(WebMock::Util::URI.variations_of_uri_as_strings(uri).sort).to eq(URIS_WITH_AUTH)
       end
     end
 
     it "should find all variations of the same uri for all variations of uri with different port" do
       URIS_WITH_DIFFERENT_PORT.each do |uri|
-        WebMock::Util::URI.variations_of_uri_as_strings(uri).sort.should == URIS_WITH_DIFFERENT_PORT
+        expect(WebMock::Util::URI.variations_of_uri_as_strings(uri).sort).to eq(URIS_WITH_DIFFERENT_PORT)
       end
     end
 
     it "should find all variations of the same uri for all variations of https uris" do
       URIS_FOR_HTTPS.each do |uri|
-        WebMock::Util::URI.variations_of_uri_as_strings(uri).sort.should == URIS_FOR_HTTPS
+        expect(WebMock::Util::URI.variations_of_uri_as_strings(uri).sort).to eq(URIS_FOR_HTTPS)
       end
     end
 
@@ -122,7 +122,7 @@ describe WebMock::Util::URI do
     it "should successfully compare all variations of the same uri with path and params" do
       URIS_WITH_PATH_AND_PARAMS.each do |uri_a|
         URIS_WITH_PATH_AND_PARAMS.each do |uri_b|
-          WebMock::Util::URI.normalize_uri(uri_a).should ===  WebMock::Util::URI.normalize_uri(uri_b)
+          expect(WebMock::Util::URI.normalize_uri(uri_a)).to be ===  WebMock::Util::URI.normalize_uri(uri_b)
         end
       end
     end
@@ -130,7 +130,7 @@ describe WebMock::Util::URI do
     it "should successfully compare all variations of the same uri with path but with params" do
       URIS_WITHOUT_PATH_BUT_WITH_PARAMS.each do |uri_a|
         URIS_WITHOUT_PATH_BUT_WITH_PARAMS.each do |uri_b|
-          WebMock::Util::URI.normalize_uri(uri_a).should ===  WebMock::Util::URI.normalize_uri(uri_b)
+          expect(WebMock::Util::URI.normalize_uri(uri_a)).to be ===  WebMock::Util::URI.normalize_uri(uri_b)
         end
       end
     end
@@ -138,7 +138,7 @@ describe WebMock::Util::URI do
     it "should successfully compare all variations of the same uri without path or params" do
       URIS_WITHOUT_PATH_OR_PARAMS.each do |uri_a|
         URIS_WITHOUT_PATH_OR_PARAMS.each do |uri_b|
-          WebMock::Util::URI.normalize_uri(uri_a).should ===  WebMock::Util::URI.normalize_uri(uri_b)
+          expect(WebMock::Util::URI.normalize_uri(uri_a)).to be ===  WebMock::Util::URI.normalize_uri(uri_b)
         end
       end
     end
@@ -146,7 +146,7 @@ describe WebMock::Util::URI do
     it "should successfully compare all variations of the same uri with authority" do
       URIS_WITH_AUTH.each do |uri_a|
         URIS_WITH_AUTH.each do |uri_b|
-          WebMock::Util::URI.normalize_uri(uri_a).should ===  WebMock::Util::URI.normalize_uri(uri_b)
+          expect(WebMock::Util::URI.normalize_uri(uri_a)).to be ===  WebMock::Util::URI.normalize_uri(uri_b)
         end
       end
     end
@@ -154,7 +154,7 @@ describe WebMock::Util::URI do
     it "should successfully compare all variations of the same uri custom port" do
       URIS_WITH_DIFFERENT_PORT.each do |uri_a|
         URIS_WITH_DIFFERENT_PORT.each do |uri_b|
-          WebMock::Util::URI.normalize_uri(uri_a).should ===  WebMock::Util::URI.normalize_uri(uri_b)
+          expect(WebMock::Util::URI.normalize_uri(uri_a)).to be ===  WebMock::Util::URI.normalize_uri(uri_b)
         end
       end
     end
@@ -162,7 +162,7 @@ describe WebMock::Util::URI do
     it "should successfully compare all variations of the same https uri" do
       URIS_FOR_HTTPS.each do |uri_a|
         URIS_FOR_HTTPS.each do |uri_b|
-          WebMock::Util::URI.normalize_uri(uri_a).should ===  WebMock::Util::URI.normalize_uri(uri_b)
+          expect(WebMock::Util::URI.normalize_uri(uri_a)).to be ===  WebMock::Util::URI.normalize_uri(uri_b)
         end
       end
     end
@@ -170,19 +170,19 @@ describe WebMock::Util::URI do
     it "should successfully handle array parameters" do
       uri_string = 'http://www.example.com:80/path?a[]=b&a[]=c'
       uri = WebMock::Util::URI.normalize_uri(uri_string)
-      WebMock::Util::QueryMapper.query_to_values(uri.query).should == {"a"=>["b", "c"]}
+      expect(WebMock::Util::QueryMapper.query_to_values(uri.query)).to eq({"a"=>["b", "c"]})
     end
 
     it "should successfully handle hash parameters" do
       uri_string = 'http://www.example.com:80/path?a[d]=b&a[e]=c&a[b][c]=1'
       uri = WebMock::Util::URI.normalize_uri(uri_string)
-      WebMock::Util::QueryMapper.query_to_values(uri.query).should == {"a"=>{"d"=>"b", "e"=>"c", "b"=>{"c"=>"1"}}}
+      expect(WebMock::Util::QueryMapper.query_to_values(uri.query)).to eq({"a"=>{"d"=>"b", "e"=>"c", "b"=>{"c"=>"1"}}})
     end
 
     it "should successfully handle nested hash parameters" do
       uri_string = 'http://www.example.com:80/path?one[two][three][]=four&one[two][three][]=five'
       uri = WebMock::Util::URI.normalize_uri(uri_string)
-      WebMock::Util::QueryMapper.query_to_values(uri.query).should == {"one"=>{"two"=>{"three" => ["four", "five"]}}}
+      expect(WebMock::Util::QueryMapper.query_to_values(uri.query)).to eq({"one"=>{"two"=>{"three" => ["four", "five"]}}})
     end
 
     it "should successfully handle mixed array and hash parameters" do
@@ -195,7 +195,7 @@ describe WebMock::Util::URI do
       # }
       uri_string = "http://www.example.com:80/path?load[include][][staff]=email&load[include][]=business_name"
       uri = WebMock::Util::URI.normalize_uri(uri_string)
-      WebMock::Util::QueryMapper.query_to_values(uri.query).should == {"load"=>{"include"=>[{"staff"=>"email"},"business_name"]}}
+      expect(WebMock::Util::QueryMapper.query_to_values(uri.query)).to eq({"load"=>{"include"=>[{"staff"=>"email"},"business_name"]}})
     end
 
     context "when query notation is set to :flat_array" do
@@ -206,7 +206,7 @@ describe WebMock::Util::URI do
       it "should successfully handle repeated paramters" do
         uri_string = "http://www.example.com:80/path?target=host1&target=host2"
         uri = WebMock::Util::URI.normalize_uri(uri_string)
-        WebMock::Util::QueryMapper.query_to_values(uri.query, :notation => WebMock::Config.instance.query_values_notation).should == [['target', 'host1'], ['target', 'host2']]
+        expect(WebMock::Util::QueryMapper.query_to_values(uri.query, :notation => WebMock::Config.instance.query_values_notation)).to eq([['target', 'host1'], ['target', 'host2']])
       end
     end
   end
@@ -216,14 +216,14 @@ describe WebMock::Util::URI do
     context "when query values is a Hash" do
       it "returns an alphabetically sorted hash" do
         sorted_query = WebMock::Util::URI.sort_query_values({"b"=>"one", "a"=>"two"})
-        sorted_query.should == {"a"=>"two", "b"=>"one"}
+        expect(sorted_query).to eq({"a"=>"two", "b"=>"one"})
       end
     end
 
     context "when query values is an Array" do
       it "returns an alphabetically sorted array" do
         sorted_query = WebMock::Util::URI.sort_query_values([["b","two"],["a","one_b"],["a","one_a"]])
-        sorted_query.should == [["a","one_a"],["a","one_b"],["b","two"]]
+        expect(sorted_query).to eq([["a","one_a"],["a","one_b"],["b","two"]])
       end
     end
   end
@@ -233,45 +233,45 @@ describe WebMock::Util::URI do
     it "should strip_default_port_from_uri strips 80 from http with path" do
       uri = "http://example.com:80/foo/bar"
       stripped_uri = WebMock::Util::URI.strip_default_port_from_uri_string(uri)
-      stripped_uri.should ==  "http://example.com/foo/bar"
+      expect(stripped_uri).to eq("http://example.com/foo/bar")
     end
 
     it "should strip_default_port_from_uri strips 80 from http without path" do
       uri = "http://example.com:80"
       stripped_uri = WebMock::Util::URI.strip_default_port_from_uri_string(uri)
-      stripped_uri.should ==  "http://example.com"
+      expect(stripped_uri).to eq("http://example.com")
     end
 
     it "should strip_default_port_from_uri strips 443 from https without path" do
       uri = "https://example.com:443"
       stripped_uri = WebMock::Util::URI.strip_default_port_from_uri_string(uri)
-      stripped_uri.should ==  "https://example.com"
+      expect(stripped_uri).to eq("https://example.com")
     end
 
     it "should strip_default_port_from_uri strips 443 from https" do
       uri = "https://example.com:443/foo/bar"
       stripped_uri = WebMock::Util::URI.strip_default_port_from_uri_string(uri)
-      stripped_uri.should == "https://example.com/foo/bar"
+      expect(stripped_uri).to eq("https://example.com/foo/bar")
     end
 
     it "should strip_default_port_from_uri does not strip 8080 from http" do
       uri = "http://example.com:8080/foo/bar"
-      WebMock::Util::URI.strip_default_port_from_uri_string(uri).should == uri
+      expect(WebMock::Util::URI.strip_default_port_from_uri_string(uri)).to eq(uri)
     end
 
     it "should strip_default_port_from_uri does not strip 443 from http" do
       uri = "http://example.com:443/foo/bar"
-      WebMock::Util::URI.strip_default_port_from_uri_string(uri).should == uri
+      expect(WebMock::Util::URI.strip_default_port_from_uri_string(uri)).to eq(uri)
     end
 
     it "should strip_default_port_from_uri does not strip 80 from query string" do
       uri = "http://example.com/?a=:80&b=c"
-      WebMock::Util::URI.strip_default_port_from_uri_string(uri).should == uri
+      expect(WebMock::Util::URI.strip_default_port_from_uri_string(uri)).to eq(uri)
     end
 
     it "should strip_default_port_from_uri does not modify strings that do not start with http or https" do
       uri = "httpz://example.com:80/"
-      WebMock::Util::URI.strip_default_port_from_uri_string(uri).should == uri
+      expect(WebMock::Util::URI.strip_default_port_from_uri_string(uri)).to eq(uri)
     end
 
   end
@@ -281,17 +281,17 @@ describe WebMock::Util::URI do
 
     it "should encode unsafe chars in userinfo does not encode userinfo safe punctuation" do
       userinfo = "user;&=+$,:secret"
-      WebMock::Util::URI.encode_unsafe_chars_in_userinfo(userinfo).should == userinfo
+      expect(WebMock::Util::URI.encode_unsafe_chars_in_userinfo(userinfo)).to eq(userinfo)
     end
 
     it "should encode unsafe chars in userinfo does not encode rfc 3986 unreserved characters" do
       userinfo = "-.!~*'()abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789:secret"
-      WebMock::Util::URI.encode_unsafe_chars_in_userinfo(userinfo).should == userinfo
+      expect(WebMock::Util::URI.encode_unsafe_chars_in_userinfo(userinfo)).to eq(userinfo)
     end
 
     it "should encode unsafe chars in userinfo does encode other characters" do
       userinfo, safe_userinfo = 'us#rn@me:sec//ret?"', 'us%23rn%40me:sec%2F%2Fret%3F%22'
-      WebMock::Util::URI.encode_unsafe_chars_in_userinfo(userinfo).should == safe_userinfo
+      expect(WebMock::Util::URI.encode_unsafe_chars_in_userinfo(userinfo)).to eq(safe_userinfo)
     end
 
   end
